<?php

declare(strict_types=1);

namespace Drupal\default_content_tools\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\DefaultContent\PreImportEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Skips importing ALL default content.
 */
final class DefaultContentImport implements EventSubscriberInterface {

  /**
   * Module's settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $settings;

  /**
   * Constructs a DefaultContentImport object.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
  ) {
    $this->settings = $configFactory->get('default_content_tools.settings');
  }

  /**
   * Kernel request event handler.
   */
  public function preImport(PreImportEvent $event): void {
    if (!$this->settings->get('suppress_import')) {
      return;
    }
    $data = $event->finder->data;
    if (count($data) === 0) {
      return;
    }
    /** @var array{_meta: array<mixed>} $decoded */
    foreach ($data as $decoded) {
      try {
        ['uuid' => $uuid] = $decoded['_meta'];
        assert(is_string($uuid));
        $event->skip($uuid, 'Default Content import is suppressed by Default Content Tools module');
      }
      catch (\Throwable $exception) {
        continue;
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      PreImportEvent::class => ['preImport'],
    ];
  }

}
