<?php

namespace Drupal\default_content_tools\Form;

use Composer\InstalledVersions;
use Drupal\Core\DefaultContent\Finder;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\default_content_tools\DefaultContentDelete;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The confirmation form.
 */
class DefaultContentDeleteForm extends ConfirmFormBase {

  /**
   * The Default Content deleter.
   *
   * @var \Drupal\default_content_tools\DefaultContentDelete
   */
  protected $deleter;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->deleter = $container->get(DefaultContentDelete::class);
    $instance->moduleHandler = $container->get('module_handler');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'default_content_tools_delete';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete default content?');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if ($package = $this->getRequest()->query->get('package')) {
      $path = InstalledVersions::getInstallPath($package);
    }
    elseif ($module = $this->getRequest()->query->get('module')) {
      $path = $this->moduleHandler->getModule($module)->getPath();
    }
    if (empty($path)) {
      $this->messenger()->addError($this->t('Unable to find extension path.'));
      return;
    }
    $finder = new Finder($path . '/content');
    if (empty($finder->data)) {
      $this->messenger()->addError($this->t('No content found.'));
      return;
    }
    $this->deleter->deleteContent($finder);
    $this->messenger()->addStatus('Default Content was deleted. Check site logs for details.');
  }

}
