<?php

declare(strict_types=1);

namespace Drupal\default_content_tools\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Default Content Tools settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'default_content_tools_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['default_content_tools.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['suppress_import'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Suppress Default Content Import'),
      '#default_value' => $this->config('default_content_tools.settings')->get('suppress_import'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('default_content_tools.settings')
      ->set('suppress_import', $form_state->getValue('suppress_import'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
