<?php

namespace Drupal\default_content_tools\Hook;

use Drupal\Core\DefaultContent\Finder;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Render\Element;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;

/**
 * Adds default content link to module list.
 */
final class Module {

  /**
   * The constructor.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   */
  public function __construct(
    protected ModuleHandlerInterface $moduleHandler,
  ) {}

  use StringTranslationTrait;

  /**
   * Implements hook_form_alter().
   */
  #[Hook(hook: 'form_system_modules_alter')]
  public function formAlter(&$form, FormStateInterface $form_state, $form_id) {
    $groups = $form['modules'] ?? [];
    foreach (Element::children($groups) as $group) {
      $modules = $form['modules'][$group] ?? [];
      foreach (Element::children($modules) as $module) {

        // Skip if module is not installed.
        if (!$this->moduleHandler->moduleExists($module)) {
          continue;
        }

        // Check if module provides default content.
        $moduleObject = $this->moduleHandler->getModule($module);
        $path = $moduleObject->getPath();
        $content = new Finder($path . '/content');
        if (empty($content->data)) {
          continue;
        }

        $form['modules'][$group][$module]['links']['default_content_tools_delete'] = [
          '#type' => 'link',
          '#title' => $this->t('Default Content <span class="visually-hidden">for @module</span>', ['@module' => $modules[$module]['name']['#markup']]),
          '#url' => Url::fromRoute('default_content_tools.delete_form', [], [
            'query' => \Drupal::destination()->getAsArray() + ['module' => $module],
          ]),
          '#options' => ['attributes' => ['class' => ['module-link', 'module-link-configure']]],
        ];
      }
    }
  }

}
