<?php

namespace Drupal\default_content_tools\Hook;

use Composer\InstalledVersions;
use Drupal\Core\DefaultContent\Finder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Url;

/**
 * Adds operation link to recipes.
 */
final class RecipeTracker {

  /**
   * Implements hook_entity_operation().
   */
  #[Hook(hook: 'entity_operation')]
  public function addOperation(EntityInterface $entity) {
    // Only show the operation link for recipe_tracker_log entities.
    if ($entity->getEntityTypeId() !== 'recipe_tracker_log') {
      return;
    }
    /** @var \Drupal\recipe_tracker\Entity\Log $entity */
    $fqn = $entity->get('package_name')->value;

    // Quit early if package name not found.
    if (!$fqn) {
      return;
    }

    // Only if version matches.
    if (InstalledVersions::getPrettyVersion($fqn) !== $entity->get('version')->value) {
      return;
    }

    // Only if contains default content.
    $path = InstalledVersions::getInstallPath($fqn);
    $content = new Finder($path . '/content');
    if (!$content->data) {
      return;
    }

    $operations = [];
    $operations['default_content_tools_delete'] = [
      'title' => t('Delete default content'),
      'url' => Url::fromRoute('default_content_tools.delete_form', [], [
        'query' => \Drupal::destination()->getAsArray() + ['package' => $fqn],
      ]),
      'weight' => 10,
    ];
    return $operations;
  }

}
